@@ -167,7 +167,21 @@ impl Cmd {
         let js = crate::api::ipc::format_callback(on_event_fn, &event)
           .expect("unable to serialize CommandEvent");
 
-        let _ = context.window.eval(js.as_str());
+        if context.window.eval(js.as_str()).is_err() {
+          fn eval<'a, R: Runtime>(
+            window: &'a crate::Window<R>,
+            js: &'a str,
+          ) -> Pin<Box<dyn Future<Output = ()> + Send + 'a>> {
+            Box::pin(async move {
+              tokio::time::sleep(std::time::Duration::from_millis(15)).await;
+              if window.eval(js).is_err() {
+                eval(window, js).await;
+              }
+            })
+          }
+
+          eval(&context.window, js.as_str()).await;
+        }
       }
     });
 
