@@ -26,8 +26,12 @@ const WIX_REQUIRED_FILES: &[&str] = &[
 /// Runs all of the commands to build the MSI installer.
 /// Returns a vector of PathBuf that shows where the MSI was created.
 pub fn bundle_project(settings: &Settings, updater: bool) -> crate::Result<Vec<PathBuf>> {
-  let mut wix_path = dirs_next::cache_dir().unwrap();
-  wix_path.push("tauri/WixTools");
+  let tauri_tools_path = settings
+    .local_tools_directory()
+    .map(|d| d.join(".tauri"))
+    .unwrap_or_else(|| dirs_next::cache_dir().unwrap().join("tauri"));
+
+  let wix_path = tauri_tools_path.join("WixTools314");
 
   if !wix_path.exists() {
     wix::get_and_extract_wix(&wix_path)?;
